==> 1.0.7.tar.gz: lib/src/backdrop_page.dart <==
import 'package:flutter/material.dart';

class BackdropPage extends StatelessWidget {
  BackdropPage({Key key, this.subTitle, @required this.child, @required this.fling})
      : assert(child != null && fling != null),
        super(key: key);
  final Text subTitle;
  final Widget child;
  final VoidCallback fling;
  @override
  Widget build(BuildContext context) => LayoutBuilder(
      builder: (context, constraints) => DecoratedBox(
            decoration: BoxDecoration(
                color: Theme.of(context).scaffoldBackgroundColor,
                borderRadius: const BorderRadius.only(topLeft: Radius.circular(16), topRight: Radius.circular(16))),
            child: Column(
              children: <Widget>[
                if (subTitle != null)
                  GestureDetector(
                    behavior: HitTestBehavior.translucent,
                    onTap: fling,
                    child: SizedBox(
                        height: 46,
                        child: Padding(
                          padding: EdgeInsets.symmetric(horizontal: 16),
                          child: Align(
                            alignment: Alignment.centerLeft,
                            child: subTitle,
                          ),
                        )),
                  ),
                GestureDetector(
                  behavior: HitTestBehavior.translucent,
                  onTap: fling,
                  child: SizedBox(
                    height: subTitle != null ? constraints.maxHeight - 46 : constraints.maxHeight,
                    width: constraints.maxWidth,
                    child: child,
                  ),
                )
              ],
            ),
          ));
}

==> 1.0.8.tar.gz: lib/src/backdrop_page.dart <==
import 'package:flutter/material.dart';

class BackdropPage extends StatelessWidget {
  BackdropPage({Key key, this.subHeader, @required this.child, @required this.fling})
      : assert(child != null && fling != null),
        super(key: key);
  final Text subHeader;
  final Widget child;
  final VoidCallback fling;
  @override
  Widget build(BuildContext context) => LayoutBuilder(
      builder: (context, constraints) => DecoratedBox(
            decoration: BoxDecoration(
                color: Theme.of(context).scaffoldBackgroundColor,
                borderRadius: const BorderRadius.only(topLeft: Radius.circular(16), topRight: Radius.circular(16))),
            child: Column(
              children: <Widget>[
                if (subHeader != null)
                  SizedBox(
                    height: 46,
                    child: Padding(
                      padding: EdgeInsets.symmetric(horizontal: 16),
                      child: Align(
                        alignment: Alignment.centerLeft,
                        child: subHeader,
                      ),
                    ),
                  ),
                GestureDetector(
                  behavior: HitTestBehavior.translucent,
                  onTap: fling,
                  child: SizedBox(
                    height: subHeader != null ? constraints.maxHeight - 46 : constraints.maxHeight,
                    width: constraints.maxWidth,
                    child: child,
                  ),
                )
              ],
            ),
          ));
}
